/*
  This file is part of KMail, the KDE mail client.
  Copyright (c) 2009 Sebastian Trueg <trueg@kde.org>

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License along
  with this program; if not, write to the Free Software Foundation, Inc.,
  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*/

#include "annotationwidget.h"

#include <nepomuk/resourceannotationmodel.h>
#include <nepomuk/annotationrelevancefiltermodel.h>
#include <nepomuk/annotation.h>
#include <nepomuk/resourcemanager.h>

#include <QHBoxLayout>
#include <QLabel>
#include <QListView>
#include <KDebug>

#include <KLocale>

Q_DECLARE_METATYPE(Nepomuk::Annotation*)

AnnotationWidget::AnnotationWidget( QWidget* parent )
  : QWidget( parent )
{
  QVBoxLayout* lay = new QVBoxLayout(this);
  m_listView = new QListView(this);
  lay->addWidget(new QLabel(i18n("Suggestions:"), this));
  lay->addWidget(m_listView);

  m_model = new Nepomuk::ResourceAnnotationModel(m_listView);
  m_model->setAutoUpdate(false);
  m_filterModel = new Nepomuk::AnnotationRelevanceFilterModel(m_model);
  m_filterModel->setSourceModel(m_model);
  m_filterModel->setSortRole(Nepomuk::AnnotationModel::RelevanceRole);
  m_filterModel->setDynamicSortFilter(true);
  m_listView->setModel(m_filterModel);

  connect(m_listView, SIGNAL(activated(QModelIndex)),
          this, SLOT(slotAnnotationExecuted(QModelIndex)));
}


AnnotationWidget::~AnnotationWidget()
{
}


void AnnotationWidget::setResource( const Nepomuk::Resource& res, const QString& content )
{
  m_model->setResource(res);
  m_model->setContent(content);
  m_filterModel->setFilterResource(res);
  m_model->updateAnnotations();
}


void AnnotationWidget::slotAnnotationExecuted( const QModelIndex& index )
{
  Nepomuk::Annotation* anno = index.data( Nepomuk::AnnotationModel::AnnotationRole ).value<Nepomuk::Annotation*>();
  connect(anno, SIGNAL(finished(Nepomuk::Annotation*)), this, SIGNAL(annotationCreated()));
  connect(anno, SIGNAL(finished(Nepomuk::Annotation*)), anno, SLOT(deleteLater()));
  anno->create(m_model->resource());
}

#include "annotationwidget.moc"
