/*
  This file is part of KMail, the KDE mail client.
  Copyright (c) 2009 Sebastian Trueg <trueg@kde.org>

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License along
  with this program; if not, write to the Free Software Foundation, Inc.,
  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*/

#include "nepomukwidget.h"

#include "kmreaderwin.h"
#include "kmmessage.h"

#include <nepomuk/annotationwidget.h>
#include <nepomuk/kmetadatatagwidget.h>
#include <nepomuk/kratingwidget.h>
#include <nepomuk/annotationmenu.h>

#include <QHBoxLayout>
#include <QLabel>
#include <KIcon>
#include <KMessageBox>
#include <QPushButton>
#include <KLocale>

#include <Nepomuk/Resource>
#include <Nepomuk/Variant>
#include <Nepomuk/Thing>

#include <KDebug>

NepomukWidget::NepomukWidget( QWidget* parent )
  : QWidget( parent )
{
  QHBoxLayout* lay = new QHBoxLayout(this);
  m_tagWidget = new Nepomuk::TagWidget(this);
  m_ratingWidget = new KRatingWidget(this);
  m_annotationWidget = new Nepomuk::AnnotationWidget(this);
  m_tasksButton = new QPushButton( i18n("More..."), this );

  lay->addWidget(m_tagWidget);
  lay->addWidget(m_ratingWidget);
  lay->addWidget(m_tasksButton);
  lay->addWidget(m_annotationWidget);

  m_tagWidget->setModeFlags( Nepomuk::TagWidget::MiniMode|Nepomuk::TagWidget::DisableTagClicking );

  connect( m_ratingWidget, SIGNAL( ratingChanged( int ) ),
           this, SLOT( slotRatingChanged( int ) ) );
  connect( m_annotationWidget, SIGNAL(annotationAdded(Nepomuk::Resource)),
           this, SIGNAL(changed()));

  connect( m_tasksButton, SIGNAL( clicked( bool )),
           this, SLOT( associateToATask() ));
}

NepomukWidget::~NepomukWidget()
{
}

void NepomukWidget::setKMReaderWin( KMReaderWin* kmreaderwin)
{
  m_kmreaderwin = kmreaderwin;
}

void NepomukWidget::associateToATask()
{
  Nepomuk::AnnotationMenu menu;
  Nepomuk::AnnotationMenu::ConfigurationFlags flags = Nepomuk::AnnotationMenu::ShowAll|Nepomuk::AnnotationMenu::UseSubMenus;
  flags &= ~Nepomuk::AnnotationMenu::ShowRatingAction;
  flags &= ~Nepomuk::AnnotationMenu::ShowTagActions;
  menu.setConfigurationFlags( flags );
  menu.setResource( m_resource );
  menu.exec( QCursor::pos() );
}

void NepomukWidget::setResource( const Nepomuk::Resource& res )
{
  m_resource = res;
  m_tagWidget->setTaggedResource( res );
  m_annotationWidget->setResource( res );
  m_ratingWidget->setRating( res.rating() );
}

void NepomukWidget::slotRatingChanged(int rating)
{
  m_resource.setRating(rating);
  emit changed();
}

#include "nepomukwidget.moc"
